prism.hmm module — prism documentation

# prism.hmm module

class `prism.hmm.` `HMMModel`(template_pattern, e_m=0.01, e_d=0.001, e_b=0.01, p=0.96, q=0.96)

  Bases: `object`

  DNMT1-like HMM model for in silico proofreading.

  `proba`(seq)

    Returns the probability of the observed methylation pattern sequence given the template pattern.

    Parameters: | seq (list) – Binary representation of methylation pattern sequence.
    Returns: | Probability of the observed methylation pattern based on the model.

`prism.hmm.` `is_methylated`(base)

  Returns True if the base denotes methylated cytosine.

  Parameters: | base (int) – Binary representation of methylation state of a cytosine.
  Returns: | True if base == 1 else False